/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWRENDER_NAMESPACE_HPP__
#define __FWRENDER_NAMESPACE_HPP__

/**
 * @brief       The namespace fwRender contains the base interface for rendering services.
 * @namespace   fwRender
 *
 * @date        2009-2010.
 *
 */
namespace fwRender
{
}
#endif /* __FWRENDER_NAMESPACE_HPP__ */
